Constant Field Values
Contents
io.microsphere.*
-
io.microsphere.multiple.active.zone.spring.DefaultZoneLocator Modifier and Type Constant Field Value public static final intDEFAULT_ORDER20 -
io.microsphere.multiple.active.zone.spring.ZoneUtils Modifier and Type Constant Field Value public static final java.lang.StringZONE_CONTEXT_BEAN_NAME"zoneContext"public static final java.lang.StringZONE_LOCATOR_BEAN_NAME"zoneLocator"